@@ -1,10 +1,10 @@
-from pandasdb.services.settings import database_configurations
 from pandasdb.services.databases import Database
+from pandasdb.services.settings import Settings
 
 
 class AllDatabases:
     def __init__(self):
-        for name, configuration in database_configurations():
+        for name, configuration in Settings.database_settings():
             setattr(self, name, Database(configuration))
 
 
